Struct amazon_sp_services::models::service_job::ServiceJob
source · [−]pub struct ServiceJob {Show 14 fields
pub create_time: Option<String>,
pub service_job_id: Option<String>,
pub service_job_status: Option<ServiceJobStatus>,
pub scope_of_work: Option<Box<ScopeOfWork>>,
pub seller: Option<Box<Seller>>,
pub service_job_provider: Option<Box<ServiceJobProvider>>,
pub preferred_appointment_times: Option<Vec<AppointmentTime>>,
pub appointments: Option<Vec<Appointment>>,
pub service_order_id: Option<String>,
pub marketplace_id: Option<String>,
pub store_id: Option<String>,
pub buyer: Option<Box<Buyer>>,
pub associated_items: Option<Vec<AssociatedItem>>,
pub service_location: Option<Box<ServiceLocation>>,
}Expand description
ServiceJob : The job details of a service.
Fields
create_time: Option<String>The date and time of the creation of the job in ISO 8601 format.
service_job_id: Option<String>Amazon identifier for the service job.
service_job_status: Option<ServiceJobStatus>The status of the service job.
scope_of_work: Option<Box<ScopeOfWork>>seller: Option<Box<Seller>>service_job_provider: Option<Box<ServiceJobProvider>>preferred_appointment_times: Option<Vec<AppointmentTime>>A list of appointment windows preferred by the buyer. Included only if the buyer selected appointment windows when creating the order.
appointments: Option<Vec<Appointment>>A list of appointments.
service_order_id: Option<String>The Amazon-defined identifier for an order placed by the buyer, in 3-7-7 format.
marketplace_id: Option<String>The marketplace identifier.
store_id: Option<String>The Amazon-defined identifier for the region scope.
buyer: Option<Box<Buyer>>associated_items: Option<Vec<AssociatedItem>>A list of items associated with the service job.
service_location: Option<Box<ServiceLocation>>Implementations
sourceimpl ServiceJob
impl ServiceJob
sourcepub fn new() -> ServiceJob
pub fn new() -> ServiceJob
The job details of a service.